==> graphql-compose-pagination-5.0.0.tgz: package/lib/__tests__/composeWithPagination-test.js <==
"use strict";

var _graphqlCompose = require("graphql-compose");

var _graphql = require("graphql-compose/lib/graphql");

var _composeWithPagination = require("../composeWithPagination");

var _User = require("../__mocks__/User");

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

describe('composeWithRelay', () => {
  const userComposer = (0, _composeWithPagination.composeWithPagination)(_User.UserTC, {
    countResolverName: 'count',
    findResolverName: 'findMany',
    perPage: 5
  });
  describe('basic checks', () => {
    it('should return ObjectTypeComposer', () => {
      expect(userComposer).toBeInstanceOf(_graphqlCompose.ObjectTypeComposer);
    });
    it('should throw error if first arg is not ObjectTypeComposer', () => {
      expect(() => {
        const args = [123];
        (0, _composeWithPagination.composeWithPagination)(...args);
      }).toThrowError('should provide ObjectTypeComposer instance');
    });
    it('should throw error if options are empty', () => {
      expect(() => {
        const args = [_User.UserTC];
        (0, _composeWithPagination.composeWithPagination)(...args);
      }).toThrowError('should provide non-empty options');
    });
    it('should not change `pagination` resolver if exists', () => {
      let myTC = _graphqlCompose.schemaComposer.createObjectTC('type Complex { a: String, b: Int }');

      myTC.addResolver({
        name: 'pagination',
        resolve: () => 'mockData'
      }); // try ovewrite `pagination` resolver

      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      expect(myTC.getResolver('pagination')).toBeTruthy();
      expect(myTC.getResolver('pagination').resolve({})).toBe('mockData');
    });
    it('should add resolver with user-specified name', () => {
      let myTC = _graphqlCompose.schemaComposer.createObjectTC('type CustomComplex { a: String, b: Int }');

      myTC.addResolver({
        name: 'count',
        resolve: () => 1
      });
      myTC.addResolver({
        name: 'findMany',
        resolve: () => ['mockData']
      });
      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        paginationResolverName: 'customPagination',
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      expect(myTC.getResolver('customPagination')).toBeTruthy();
      expect(myTC.hasResolver('pagination')).toBeFalsy();
    });
    it('should add two connection resolvers', () => {
      let myTC = _graphqlCompose.schemaComposer.createObjectTC('type CustomComplex { a: String, b: Int }');

      myTC.addResolver({
        name: 'count',
        resolve: () => 1
      });
      myTC.addResolver({
        name: 'findMany',
        resolve: () => ['mockData']
      });
      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        paginationResolverName: 'customPagination',
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      expect(myTC.hasResolver('pagination')).toBeTruthy();
      expect(myTC.getResolver('customPagination')).toBeTruthy();
    });
  });
  describe('check `pagination` resolver props', () => {
    const rsv = userComposer.getResolver('pagination');
    const type = rsv.getType();

    const tc = _graphqlCompose.schemaComposer.createObjectTC(type);

    it('should exists', () => {
      expect(rsv).toBeTruthy();
    });
    it('should has PaginationType as type', () => {
      expect(type).toBeTruthy();
      expect(tc.getFieldNames()).toEqual(expect.arrayContaining(['count', 'pageInfo', 'items']));
      expect(tc.getFieldType('items')).toBeInstanceOf(_graphql.GraphQLList);
    });
  });
  describe('fragments fields projection of graphql-compose', () => {
    it('should return object',
    /*#__PURE__*/
    _asyncToGenerator(function* () {
      _graphqlCompose.schemaComposer.Query.setField('userPagination', _User.UserTC.getResolver('pagination'));

      const schema = _graphqlCompose.schemaComposer.buildSchema();

      const query = `{
        userPagination(page: 1, perPage: 2) {
          count,
          pageInfo {
            currentPage
            perPage
            itemCount
            pageCount
            ...on PaginationInfo {
              hasPreviousPage
              hasNextPage
            }
          }
          items {
            id
            name
            ...idNameAge
            ...on User {
              age
            }
          }
        }
      }
      fragment idNameAge on User {
        gender
      }
      `;
      const result = yield (0, _graphql.graphql)(schema, query);
      expect(result).toEqual({
        data: {
          userPagination: {
            count: 15,
            items: [{
              age: 18,
              gender: 'm',
              id: 8,
              name: 'user08'
            }, {
              age: 11,
              gender: 'm',
              id: 1,
              name: 'user01'
            }],
            pageInfo: {
              currentPage: 1,
              hasNextPage: true,
              hasPreviousPage: false,
              itemCount: 15,
              pageCount: 8,
              perPage: 2
            }
          }
        }
      });
    }));
  });
  it('should pass `countResolveParams` to top resolverParams',
  /*#__PURE__*/
  _asyncToGenerator(function* () {
    let topResolveParams = {};

    _graphqlCompose.schemaComposer.Query.setField('userPagination', _User.UserTC.getResolver('pagination').wrapResolve(next => rp => {
      const result = next(rp);
      topResolveParams = rp;
      return result;
    }));

    const schema = _graphqlCompose.schemaComposer.buildSchema();

    const query = `{
      userPagination(filter: { age: 45 }) {
        count
      }
    }`;
    yield (0, _graphql.graphql)(schema, query);
    expect(Object.keys(topResolveParams.countResolveParams)).toEqual(expect.arrayContaining(['source', 'args', 'context', 'info', 'projection']));
    expect(topResolveParams.countResolveParams.args).toEqual({
      filter: {
        age: 45
      }
    });
  }));
  it('should pass `findManyResolveParams` to top resolverParams',
  /*#__PURE__*/
  _asyncToGenerator(function* () {
    let topResolveParams = {};

    _graphqlCompose.schemaComposer.Query.setField('userPagination', _User.UserTC.getResolver('pagination').wrapResolve(next => rp => {
      const result = next(rp);
      topResolveParams = rp;
      return result;
    }));

    const schema = _graphqlCompose.schemaComposer.buildSchema();

    const query = `{
      userPagination(filter: { age: 45 }) {
        count
      }
    }`;
    yield (0, _graphql.graphql)(schema, query);
    expect(Object.keys(topResolveParams.findManyResolveParams)).toEqual(expect.arrayContaining(['source', 'args', 'context', 'info', 'projection']));
    expect(topResolveParams.findManyResolveParams.args).toEqual({
      filter: {
        age: 45
      },
      limit: 6,
      perPage: 5
    });
  }));
});

==> graphql-compose-pagination-6.0.0.tgz: package/lib/__tests__/composeWithPagination-test.js <==
"use strict";

var _graphqlCompose = require("graphql-compose");

var _graphql = require("graphql-compose/lib/graphql");

var _composeWithPagination = require("../composeWithPagination");

var _User = require("../__mocks__/User");

/* eslint-disable no-param-reassign */
describe('composeWithRelay', () => {
  const userComposer = (0, _composeWithPagination.composeWithPagination)(_User.UserTC, {
    countResolverName: 'count',
    findResolverName: 'findMany',
    perPage: 5
  });
  describe('basic checks', () => {
    it('should return ObjectTypeComposer', () => {
      expect(userComposer).toBeInstanceOf(_graphqlCompose.ObjectTypeComposer);
    });
    it('should throw error if first arg is not ObjectTypeComposer', () => {
      expect(() => {
        const args = [123];
        (0, _composeWithPagination.composeWithPagination)(...args);
      }).toThrowError('should provide ObjectTypeComposer instance');
    });
    it('should throw error if options are empty', () => {
      expect(() => {
        const args = [_User.UserTC];
        (0, _composeWithPagination.composeWithPagination)(...args);
      }).toThrowError('should provide non-empty options');
    });
    it('should not change `pagination` resolver if exists', () => {
      let myTC = _graphqlCompose.schemaComposer.createObjectTC('type Complex { a: String, b: Int }');

      myTC.addResolver({
        name: 'pagination',
        resolve: () => 'mockData'
      }); // try ovewrite `pagination` resolver

      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      expect(myTC.getResolver('pagination')).toBeTruthy();
      expect(myTC.getResolver('pagination').resolve({})).toBe('mockData');
    });
    it('should add resolver with user-specified name', () => {
      let myTC = _graphqlCompose.schemaComposer.createObjectTC('type CustomComplex { a: String, b: Int }');

      myTC.addResolver({
        name: 'count',
        resolve: () => 1
      });
      myTC.addResolver({
        name: 'findMany',
        resolve: () => ['mockData']
      });
      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        paginationResolverName: 'customPagination',
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      expect(myTC.getResolver('customPagination')).toBeTruthy();
      expect(myTC.hasResolver('pagination')).toBeFalsy();
    });
    it('should add two connection resolvers', () => {
      let myTC = _graphqlCompose.schemaComposer.createObjectTC('type CustomComplex { a: String, b: Int }');

      myTC.addResolver({
        name: 'count',
        resolve: () => 1
      });
      myTC.addResolver({
        name: 'findMany',
        resolve: () => ['mockData']
      });
      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      myTC = (0, _composeWithPagination.composeWithPagination)(myTC, {
        paginationResolverName: 'customPagination',
        countResolverName: 'count',
        findResolverName: 'findMany'
      });
      expect(myTC.hasResolver('pagination')).toBeTruthy();
      expect(myTC.getResolver('customPagination')).toBeTruthy();
    });
  });
  describe('check `pagination` resolver props', () => {
    const rsv = userComposer.getResolver('pagination');
    const type = rsv.getType();

    const tc = _graphqlCompose.schemaComposer.createObjectTC(type);

    it('should exists', () => {
      expect(rsv).toBeTruthy();
    });
    it('should has PaginationType as type', () => {
      expect(type).toBeTruthy();
      expect(tc.getFieldNames()).toEqual(expect.arrayContaining(['count', 'pageInfo', 'items']));
      expect(tc.getFieldType('items')).toBeInstanceOf(_graphql.GraphQLList);
    });
  });
  describe('fragments fields projection of graphql-compose', () => {
    it('should return object', async () => {
      _graphqlCompose.schemaComposer.Query.setField('userPagination', _User.UserTC.getResolver('pagination'));

      const schema = _graphqlCompose.schemaComposer.buildSchema();

      const query = `{
        userPagination(page: 1, perPage: 2) {
          count,
          pageInfo {
            currentPage
            perPage
            itemCount
            pageCount
            ...on PaginationInfo {
              hasPreviousPage
              hasNextPage
            }
          }
          items {
            id
            name
            ...idNameAge
            ...on User {
              age
            }
          }
        }
      }
      fragment idNameAge on User {
        gender
      }
      `;
      const result = await (0, _graphql.graphql)(schema, query);
      expect(result).toEqual({
        data: {
          userPagination: {
            count: 15,
            items: [{
              age: 18,
              gender: 'm',
              id: 8,
              name: 'user08'
            }, {
              age: 11,
              gender: 'm',
              id: 1,
              name: 'user01'
            }],
            pageInfo: {
              currentPage: 1,
              hasNextPage: true,
              hasPreviousPage: false,
              itemCount: 15,
              pageCount: 8,
              perPage: 2
            }
          }
        }
      });
    });
  });
  it('should pass `countResolveParams` to top resolverParams', async () => {
    let topResolveParams = {};

    _graphqlCompose.schemaComposer.Query.setField('userPagination', _User.UserTC.getResolver('pagination').wrapResolve(next => rp => {
      const result = next(rp);
      topResolveParams = rp;
      return result;
    }));

    const schema = _graphqlCompose.schemaComposer.buildSchema();

    const query = `{
      userPagination(filter: { age: 45 }) {
        count
      }
    }`;
    await (0, _graphql.graphql)(schema, query);
    expect(Object.keys(topResolveParams.countResolveParams)).toEqual(expect.arrayContaining(['source', 'args', 'context', 'info', 'projection']));
    expect(topResolveParams.countResolveParams.args).toEqual({
      filter: {
        age: 45
      }
    });
  });
  it('should pass `findManyResolveParams` to top resolverParams', async () => {
    let topResolveParams = {};

    _graphqlCompose.schemaComposer.Query.setField('userPagination', _User.UserTC.getResolver('pagination').wrapResolve(next => rp => {
      const result = next(rp);
      topResolveParams = rp;
      return result;
    }));

    const schema = _graphqlCompose.schemaComposer.buildSchema();

    const query = `{
      userPagination(filter: { age: 45 }) {
        count
      }
    }`;
    await (0, _graphql.graphql)(schema, query);
    expect(Object.keys(topResolveParams.findManyResolveParams)).toEqual(expect.arrayContaining(['source', 'args', 'context', 'info', 'projection']));
    expect(topResolveParams.findManyResolveParams.args).toEqual({
      filter: {
        age: 45
      },
      limit: 6,
      perPage: 5
    });
  });
});
